@@ -15,7 +15,7 @@ keras_msg = (
     "To use afqinsight's convolutional neural nets for tractometry data, you will need "
     "to have tensorflow and kerastuner installed. You can do this by installing "
     "afqinsight with `pip install afqinsight[tf]`, or by separately installing these packages "
-    "with `pip install tensorflow kerastuner`."
+    "with `pip install tensorflow keras-tuner`."
 )
 
 kt, _, _ = optional_package("keras_tuner", keras_msg)
